@@ -20,7 +20,7 @@ from tenacity import retry, stop_after_attempt, wait_fixed, retry_if_exception_t
 # code from https://towardsdatascience.com/decoding-ethereum-smart-contract-data-eed513a65f76
 
 
-from crypto_scan.configs import ETHNET, POLYGONNET, CHAIN_OPTIONS, ETH_CHAIN, POLYGON_CHAIN
+from crypto_scan.configs import ETHNET, POLYGONNET, CHAIN_OPTIONS, ETH_CHAIN, POLYGON_CHAIN, ETHERSCAN_URL, POLYSCAN_URL
 
 
 # decode transactions
@@ -124,6 +124,15 @@ def _get_hex_topic(t):
 # code from https://towardsdatascience.com/decoding-ethereum-smart-contract-data-eed513a65f76
 
 
+def get_scan_url(chain: CHAIN_OPTIONS, addr: str) -> str:
+    if chain == ETH_CHAIN:
+        return f"{ETHERSCAN_URL}/address/{addr}"
+    elif chain == POLYGON_CHAIN:
+        return f"{POLYSCAN_URL}/address/{addr}"
+    else:
+        raise Exception("Unhandled chain: {chain}")
+
+
 class Scan:
 
     def __init__(self, chain: CHAIN_OPTIONS, api_key: str):
